<?php

class Api_Emailsequence_Emailsequence extends Api_Service_Abstract
{


    /**
     * System response helper
     *
     * @var null
     */
    protected $_responseHelper = null;

    /**
     * System translate helper
     *
     * @var null
     */
    protected $_translator = null;


    /**
     * Mandatory fields
     *
     * @var array
     */
    protected $_mandatoryParams = array('sequence_name');

    /**
     * Email sequence secure token
     */
    const EMAIL_SEQUENCE_SECURE_TOKEN = 'EmailSequenceToken';

    /**
     * @var array Access Control List
     */
    protected $_accessList = array(
        Tools_Security_Acl::ROLE_SUPERADMIN => array(
            'allow' => array('get', 'post', 'put', 'delete')
        ),
        Tools_Security_Acl::ROLE_ADMIN => array(
            'allow' => array('get', 'post', 'put', 'delete')
        ),
        Shopping::ROLE_SALESPERSON => array(
            'allow' => array('get', 'post', 'put', 'delete')
        )
    );

    /**
     * init
     */
    public function init()
    {
        parent::init();
        $this->_responseHelper = Zend_Controller_Action_HelperBroker::getStaticHelper('response');
        $this->_translator = Zend_Registry::get('Zend_Translate');
    }

    /**
     * Get email sequence
     *
     * Resourse:
     * : /api/emailsequence/emailsequence/id/:id
     *
     * HttpMethod:
     * : GET
     *
     * ## Parameters:
     * * id (type integer)
     * : id
     *
     * @return JSON List of groups
     */
    public function getAction()
    {
        $id = filter_var($this->_request->getParam('id'), FILTER_SANITIZE_NUMBER_INT);
        $withoutPagination = filter_var($this->_request->getParam('withoutPagination'), FILTER_SANITIZE_NUMBER_INT);
        $searchTerm = filter_var($this->_request->getParam('searchTerm'), FILTER_SANITIZE_STRING);
        $emailSequenceMapper = Emailsequence_Models_Mapper_EmailSequenceSettingsMapper::getInstance();
        $data = array();
        if (!empty($id)) {
            $emailSequenceMapper->find($id);
        } elseif(!empty($withoutPagination)) {
            if (!empty($searchTerm)) {
                $where = $emailSequenceMapper->getDbTable()->getAdapter()->quoteInto('sequence_name LIKE ?', '%'.$searchTerm.'%');
                $data = $emailSequenceMapper->getSequences($where);
            } else {
                $data = $emailSequenceMapper->getSequences();
            }
        } else {
           $data = $emailSequenceMapper->getEmailSequenceList();
        }

        if (!empty($data) && empty($withoutPagination)) {
            $data['triggers'] = $emailSequenceMapper->getAllTriggers();
        }


        return $data;

    }

    /**
     * New email sequence config settings
     *
     * Resourse:
     * : /api/emailsequence/emailsequence/
     *
     * HttpMethod:
     * : POST
     *
     * @return JSON Email sequence model
     */
    public function postAction()
    {
        $data = filter_var_array($this->getRequest()->getParams(), FILTER_SANITIZE_STRING);


        $fieldDataMissing = array_filter($this->_mandatoryParams, function ($param) use ($data) {
            if (!array_key_exists($param, $data) || empty($data[$param])) {
                return $param;
            }
        });

        if (!empty($fieldDataMissing)) {
            $this->_error($this->_translator->translate('Missing mandatory params'));
        }

        $emailSequenceMapper = Emailsequence_Models_Mapper_EmailSequenceSettingsMapper::getInstance();
        $data['sequence_name'] = trim($data['sequence_name']);
        $emailSequenceModel = $emailSequenceMapper->findBySequenceName($data['sequence_name']);
        if ($emailSequenceModel instanceof Emailsequence_Models_Models_EmailSequenceSettingsModel) {
            $this->_error($this->_translator->translate('Sequence with such name already exists'));
        }

        $emailSequenceModel = new Emailsequence_Models_Models_EmailSequenceSettingsModel();
        $emailSequenceModel->setSequenceName($data['sequence_name']);
        $emailSequenceModel = $emailSequenceMapper->save($emailSequenceModel);

        $this->_responseHelper->success(array(
            'message' => $this->_translator->translate('Sequence has been created'),
            'sequenceId' => $emailSequenceModel->getId()
        ));
    }

    /**
     *
     * Resourse:
     * : /api/emailsequence/emailsequence/
     *
     * HttpMethod:
     * : PUT
     *
     * @return  JSON Email sequence model
     */
    public function putAction()
    {

    }

    /**
     * Delete email sequence
     *
     * Resourse:
     * : /api/emailsequence/emailsequence/
     *
     * HttpMethod:
     * : DELETE
     *
     * ## Parameters:
     * id (type integer)
     * : sequence id to delete
     *
     * @return JSON Result of removing cart status email
     */
    public function deleteAction()
    {
        $id = filter_var($this->_request->getParam('id'), FILTER_SANITIZE_NUMBER_INT);

        if (empty($id)) {
            $this->_error($this->_translator->translate('id missing'));
        }
        $emailSequenceMapper = Emailsequence_Models_Mapper_EmailSequenceSettingsMapper::getInstance();
        $emailSequenceModel = $emailSequenceMapper->find($id);
        if ($emailSequenceModel instanceof Emailsequence_Models_Models_EmailSequenceSettingsModel) {
            $emailSequenceMapper->deleteSequence($id);
            $this->_responseHelper->success($this->_translator->translate('Sequence has been deleted'));
        }

        $this->_error($this->_translator->translate('Sequence doesn\'t exist'));
    }

}
