define([
    'backbone',
    './lead-event-rules-grid',
    './lead-event-rules-form',
    './lead-form-rules',
    './lead-form-rules-grid',
    './lead-builder-form',
    './lead-builder-grid',
    'i18n!../../../nls/dashboard_'+$('#main-dashboard-system-language').val()+'_ln'
], function(Backbone, LeadEventRulesView, LeadEventRulesFormView, LeadFormRulesView, LeadFormRulesGridView, LeadBuilderFormView, LeadBuilderGridView, i18n
){

    var LeadsFormMainView = Backbone.View.extend({
        el: $('#lead-form-block'),
        events: {
            'click a[data-role=lead-rules-detailed-view]': 'showLeadFormDetailsScreen',
            'click a[data-role=event-rules-detailed-view]': 'showLeadEventDetailsScreen',
            'click a[data-role=form-builder-detailed-view]': 'showFormBuilderDetailsScreen',
            'click #lead-form-block-tabs-tab li' : 'showLeadFormTabs',
            'click #form-rules-grid-back-link': 'returnRulesMainTab',
            'click #event-rules-grid-back-link': 'returnFromEventToMainTab',
            'click #form-builder-grid-back-link': 'returnFromFormBuilderMainTab'
        },
        templates: {},
        initialize: function(options){

        },
        render: function(){

        },
        showLeadFormDetailsScreen: function(e)
        {
            var ruleId = $(e.currentTarget).closest('tr').data('rule-id');
            if (!ruleId) {
                return false;
            }
            window.appLeadFormRouter.leadFormRulesDetails(ruleId);
        },
        showLeadEventDetailsScreen: function(e)
        {
            var ruleId = $(e.currentTarget).closest('tr').data('rule-id');
            if (!ruleId) {
                return false;
            }
            window.appLeadFormRouter.leadEventsDetails(ruleId);
        },
        showFormBuilderDetailsScreen: function(e)
        {
            var formId = $(e.currentTarget).closest('tr').data('rule-id');
            if (!formId) {
                return false;
            }
            window.appLeadFormRouter.leadFormBuildDetails(formId);
        },
        returnRulesMainTab: function(e)
        {
            e.preventDefault();
            $('#lead-form-rules-detailed-view-block').empty();
            $('#lead-form-block-tabs-tab').removeClass('hidden');
            $('#lead-form-block-tabs-block').removeClass('hidden');

        },
        returnFromEventToMainTab: function(e)
        {
            e.preventDefault();
            $('#lead-event-rules-detailed-view-block').empty();
            $('#lead-event-block-tabs-tab').removeClass('hidden');
            $('#lead-form-block-tabs-block').removeClass('hidden');

        },
        returnFromFormBuilderMainTab: function(e)
        {
            e.preventDefault();
            $('#lead-form-builder-form-detailed-block').empty();
            $('#lead-event-block-tabs-tab').removeClass('hidden');
            $('#lead-form-block-tabs-block').removeClass('hidden');
            $('.form-builder-form-type').first().trigger('click');

        },
        showLeadFormTabs: function(e)
        {
            var el = $(e.currentTarget),
                tabBlockContentId = el.data('tab-id'),
                tabContentName = el.data('tab-name'),
                tabBlockContentEl = $('#'+tabBlockContentId),
                self = this,
                tabContentBlock = el.closest('#lead-form-block-tabs-block').find('.lead-form-block-tabs-content');

            if (el.hasClass('current')) {
                return false;
            }

            $('#lead-form-create-form-rule-block').empty();
            $('#lead-event-create-rule-form-block').empty();
            $('#lead-form-builder-form-block').empty();

            if (tabBlockContentEl.hasClass('hidden')) {
                if (tabContentName === 'form-rules') {
                    if(!_.isUndefined(this.formRulesFormView)) {
                        this.formRulesFormView.$el.unbind();
                    }
                    if(!_.isUndefined(this.formRulesGridView)) {
                        this.formRulesGridView.$el.unbind();
                    }
                    this.formRulesFormView = new LeadFormRulesView();
                    this.formRulesGridView = new LeadFormRulesGridView();
                    self.assign({
                        '#form-rules-grid-table': this.formRulesGridView,
                        '#lead-form-create-form-rule-block' : this.formRulesFormView
                    });

                    this.formRulesFormView.$el.on('LeadFormRulesFormGrid:created', _.bind(this.formRulesGridView.render, this.formRulesGridView));
                    self.hideTab(tabBlockContentEl, el);
                }

                if (tabContentName === 'form-builder') {
                    if(!_.isUndefined(this.LeadBuilderGridView)) {
                        this.LeadBuilderGridView.$el.unbind();
                    }
                    if(!_.isUndefined(this.LeadBuilderFormView)) {
                        this.LeadBuilderFormView.$el.unbind();
                    }
                    this.LeadBuilderFormView = new LeadBuilderFormView();
                    this.LeadBuilderGridView = new LeadBuilderGridView();
                    self.assign({
                        '#lead-form-builder-grid-table': this.LeadBuilderGridView,
                        '#lead-form-builder-form-block' : this.LeadBuilderFormView
                    });

                    this.LeadBuilderFormView.$el.on('LeadBuilderFormGrid:created', _.bind(this.LeadBuilderGridView.render, this.LeadBuilderGridView));
                    self.hideTab(tabBlockContentEl, el);
                }

                if (tabContentName === 'event-rules') {
                    if(!_.isUndefined(this.eventRulesGridView)) {
                        this.eventRulesGridView.$el.unbind();
                    }
                    if(!_.isUndefined(this.eventRulesFormView)) {
                        this.eventRulesFormView.$el.unbind();
                    }
                    this.eventRulesGridView = new LeadEventRulesView();
                    this.eventRulesFormView = new LeadEventRulesFormView();
                    self.assign({
                        '#event-rules-grid-table': this.eventRulesGridView,
                        '#lead-event-create-rule-form-block' : this.eventRulesFormView
                    });

                    this.eventRulesFormView.$el.on('LeadEventRulesGrid:created', _.bind(this.eventRulesGridView.render, this.eventRulesGridView));
                    self.hideTab(tabBlockContentEl, el);
                }
            }

            tabContentBlock.addClass('hidden');
            $('#lead-form-block-tabs-tab').find('li').removeClass('current');
            this.hideTab(tabBlockContentEl, el);
        },
        hideTab: function (tabBlockContentEl, el){
            tabBlockContentEl.removeClass('hidden');
            el.closest('li').addClass('current');
        },
        assign: function (selector, view) {
            var selectors;
            if (_.isObject(selector)) {
                selectors = selector;
            }
            else {
                selectors = {};
                selectors[selector] = view;
            }
            if (!selectors) return;
            _.each(selectors, function (view, selector) {
                view.setElement(this.$(selector)).render();
            }, this);
        }
    });

    return LeadsFormMainView;
});