define([
    'backbone',
    '../collections/lead-reports',
    'text!../templates/graph-placeholder.html',
    'text!../templates/card-comparison.html',
    'text!../templates/card-comparison-pie.html',
    'i18n!../../../nls/dashboard_'+$('#lead-reports-system-language').val()+'_ln',
    'moment',
    'c3',
    'D3Funnel',
    'accounting'
], function(Backbone, LeadReportsCollection, GraphPlaceholderTmpl, CardComparisonTmpl, CardComparisonPieTmpl, i18n, moment, c3, D3Funnel, accounting
){

    var LeadReportsView = Backbone.View.extend({
        el: $('#lead-reports-view-tabs-block'),
        events: {
            'click #lead-reports-view-tabs li': 'showLeadReportsTab',
            'click .switch-card-comparison': 'switchCardComparison'
        },
        templates: {
        },
        initialize: function(){
            this.LeadReportsCollection = new LeadReportsCollection();
            this.LeadReportsCollection.on('reset', this.renderTabContent, this);
            this.LeadReportsCollection.on('add', this.renderTabContent, this);
            this.LeadReportsCollection.on('destroy', this.renderTabContent, this);
        },
        render: function() {
            var tabEl = $('.lead-report-tab.current'),
                graphTypes = $(tabEl).data('report-graphs').split(','),
                tabContentName =  $(tabEl).data('tab-name'),
                leadReportsCompare = 0,
                leadReportsFilterStartDate = ($('#lead-reports-filter-start-date').val()) ? $.datepicker.formatDate('yy-mm-dd', $('#lead-reports-filter-start-date').datepicker("getDate")): '',
                leadReportsFilterEndDate =  ($('#lead-reports-filter-end-date').val()) ? $.datepicker.formatDate('yy-mm-dd', $('#lead-reports-filter-end-date').datepicker("getDate")): '',
                leadReportsCompareFilterStartDate = ($('#lead-reports-filter-compare-start-date').val()) ? $.datepicker.formatDate('yy-mm-dd', $('#lead-reports-filter-compare-start-date').datepicker("getDate")): '',
                leadReportsCompareFilterEndDate = ($('#lead-reports-filter-compare-end-date').val()) ? $.datepicker.formatDate('yy-mm-dd', $('#lead-reports-filter-compare-end-date').datepicker("getDate")): '';

            if ($('#lead-reports-compare').is(':checked')) {
                leadReportsCompare = 1;
            }

            this.LeadReportsCollection.server_api.graphTypes = graphTypes;
            this.LeadReportsCollection.server_api.tabContentName = tabContentName;
            this.LeadReportsCollection.server_api.leadReportsCompare = leadReportsCompare;
            this.LeadReportsCollection.server_api.leadReportsFilterStartDate = leadReportsFilterStartDate;
            this.LeadReportsCollection.server_api.leadReportsFilterEndDate = leadReportsFilterEndDate;
            this.LeadReportsCollection.server_api.leadReportsCompareFilterStartDate = leadReportsCompareFilterStartDate;
            this.LeadReportsCollection.server_api.leadReportsCompareFilterEndDate = leadReportsCompareFilterEndDate;
            this.LeadReportsCollection.pager();
            return this;
        },
        renderTabContent: function(tabContentName) {
            var tabName = this.LeadReportsCollection.tabContentName,
                graphs = this.LeadReportsCollection.graphs;

            if (tabName === 'sales-rep') {
                if (typeof graphs.byRep !== 'undefined') {
                    $('#lead-report-by-rep').empty();
                    $('#lead-report-by-rep-card-comparison').empty();
                    $('#lead-report-by-rep').removeClass('no-graph-data');
                    if (typeof graphs.byRep.axes !== 'undefined') {
                        if (typeof graphs.byRep.dataToCompare !== 'undefined') {
                            chartData = [
                                graphs.byRep.axes,
                                graphs.byRep.data,
                                graphs.byRep.dataToCompare
                            ];
                        } else {
                            chartData = [
                                graphs.byRep.axes,
                                graphs.byRep.data
                            ];
                        }
                        this.createBarChart(chartData, '#lead-report-by-rep', 45, {
                            colorPattern: graphs.byRep.colorPattern,
                            labels: true,
                            title: graphs.byRep.title,
                            customYAxisFormat: {
                                type: 'onlyInteger'
                            },
                            showLegend : true
                        });
                        if (typeof graphs.byRep.dataToCompare !== 'undefined') {
                            $('#lead-report-by-rep').find('svg').before(_.template(CardComparisonTmpl, {'comparisonData': graphs.byRep.comparisonData, 'i18n': i18n}));
                        }
                    } else {
                        $('#lead-report-by-rep').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n}));
                        $('#lead-report-by-rep').addClass('no-graph-data');
                    }
                }

                if (typeof graphs.opportunitiesCountPerRep !== 'undefined') {
                    $('#lead-report-opportunities-count-per-rep').empty();
                    $('#lead-report-opportunities-count-per-rep-card-comparison').empty();
                    $('#lead-report-opportunities-count-per-rep').removeClass('no-graph-data');
                    if (typeof graphs.opportunitiesCountPerRep.axes !== 'undefined') {
                        if (typeof graphs.opportunitiesCountPerRep.dataToCompare !== 'undefined') {
                            chartData = [
                                graphs.opportunitiesCountPerRep.axes,
                                graphs.opportunitiesCountPerRep.data,
                                graphs.opportunitiesCountPerRep.dataToCompare
                            ];
                        } else {
                            chartData = [
                                graphs.opportunitiesCountPerRep.axes,
                                graphs.opportunitiesCountPerRep.data
                            ];
                        }
                        this.createBarChart(chartData, '#lead-report-opportunities-count-per-rep', 45, {
                            colorPattern: graphs.opportunitiesCountPerRep.colorPattern,
                            labels: true,
                            title: graphs.opportunitiesCountPerRep.title,
                            customYAxisFormat: {
                                type: 'onlyInteger'
                            },
                            showLegend : true
                        });
                        if (typeof graphs.opportunitiesCountPerRep.dataToCompare !== 'undefined') {
                            $('#lead-report-opportunities-count-per-rep').find('svg').before(_.template(CardComparisonTmpl, {'comparisonData': graphs.opportunitiesCountPerRep.comparisonData, 'i18n': i18n}));
                        }
                    } else {
                        $('#lead-report-opportunities-count-per-rep').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n}));
                        $('#lead-report-opportunities-count-per-rep').addClass('no-graph-data');
                    }
                }

                if (typeof graphs.opportunitiesAmountPerRep !== 'undefined') {
                    $('#lead-report-opportunities-amount-per-rep').empty();
                    $('#lead-report-opportunities-amount-per-rep-card-comparison').empty();
                    $('#lead-report-opportunities-amount-per-rep').removeClass('no-graph-data');
                    if (typeof graphs.opportunitiesAmountPerRep.axes !== 'undefined') {
                        if (typeof graphs.opportunitiesAmountPerRep.dataToCompare !== 'undefined') {
                            chartData = [
                                graphs.opportunitiesAmountPerRep.axes,
                                graphs.opportunitiesAmountPerRep.data,
                                graphs.opportunitiesAmountPerRep.dataToCompare
                            ];
                        } else {
                            chartData = [
                                graphs.opportunitiesAmountPerRep.axes,
                                graphs.opportunitiesAmountPerRep.data
                            ];
                        }

                        this.createBarChart(chartData, '#lead-report-opportunities-amount-per-rep', 45, {
                            customYAxisFormat: {
                                type: 'currency',
                                sign: this.LeadReportsCollection.currencySymbol

                            },
                            colorPattern: graphs.opportunitiesAmountPerRep.colorPattern,
                            labels: {
                                type: 'currency',
                                sign: this.LeadReportsCollection.currencySymbol
                            },
                            title: graphs.opportunitiesAmountPerRep.title,
                            showLegend : true
                        });
                        if (typeof graphs.opportunitiesAmountPerRep.dataToCompare !== 'undefined') {
                            $('#lead-report-opportunities-amount-per-rep').find('svg').before(_.template(CardComparisonTmpl, {'comparisonData': graphs.opportunitiesAmountPerRep.comparisonData, 'i18n': i18n}));
                        }
                    } else {
                        $('#lead-report-opportunities-amount-per-rep').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n}));
                        $('#lead-report-opportunities-amount-per-rep').addClass('no-graph-data');
                    }
                }

                if (typeof graphs.tasksCountPerRep !== 'undefined') {
                    $('#lead-report-tasks-count-per-rep').empty();
                    $('#lead-report-tasks-count-per-rep-legend').remove();
                    $('#lead-report-tasks-count-per-rep-card-comparison').empty();
                    $('#lead-report-tasks-count-per-rep').removeClass('no-graph-data');
                    if (typeof graphs.tasksCountPerRep.axes !== 'undefined') {
                        chartData = [
                            graphs.tasksCountPerRep.axes
                        ];


                        var dataGroupFrom = graphs.tasksCountPerRep.dataGroupFrom,
                            groups = [],
                            onlyData = [],
                            compare = false;

                        groups.push(dataGroupFrom);

                        $.each(graphs.tasksCountPerRep.data, function(opportunity, graphData){
                            var cleanLegendId = '';
                            if (!_.isArray(graphData)) {
                                var dataArr = [];
                                $.each(graphData, function(key, elem){
                                    dataArr[key] = elem;
                                });
                                chartData.push(dataArr);
                            } else {
                                chartData.push(graphData);
                            }

                            if (graphData[0].match(/\*/) !== null) {
                                cleanLegendId = graphData[0].substring(1);
                            } else {
                                cleanLegendId = graphData[0];
                            }
                            if (_.indexOf(onlyData, cleanLegendId) == '-1') {
                                onlyData.push(cleanLegendId);
                            }
                        });

                        if (typeof graphs.tasksCountPerRep.dataToCompare !== 'undefined') {
                            groups.push(graphs.tasksCountPerRep.dataGroupTo);
                            compare = true;
                        }
                        this.createBarChart(chartData, '#lead-report-tasks-count-per-rep', 45, {
                            groups:groups,
                            colorPattern: graphs.tasksCountPerRep.colorPattern,
                            title: graphs.tasksCountPerRep.title,
                            customYAxisFormat: {
                                type: 'onlyInteger'
                            },
                            tooltip: {filterFromDate: graphs.tasksCountPerRep.filterFromDate, filterToDate: graphs.tasksCountPerRep.filterToDate, compare:compare}
                        });

                        $('#lead-report-tasks-count-per-rep').find('svg').closest('div').after('<div id="lead-report-tasks-count-per-rep-legend"></div>');
                        this.createCustomLegend('#lead-report-tasks-count-per-rep-legend', '#lead-report-tasks-count-per-rep', onlyData,  graphs.tasksCountPerRep.fullColorPattern);
                        if (typeof graphs.tasksCountPerRep.dataToCompare !== 'undefined') {
                            $('#lead-report-tasks-count-per-rep').find('svg').before(_.template(CardComparisonTmpl, {'comparisonData': graphs.tasksCountPerRep.comparisonData, 'i18n': i18n}));
                        }
                    } else {
                        $('#lead-report-tasks-count-per-rep').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n}));
                        $('#lead-report-tasks-count-per-rep').addClass('no-graph-data');
                    }
                }

                if (typeof graphs.opportunitiesStagePerRep !== 'undefined') {
                    $('#lead-report-opportunities-stage-per-rep-tooltip').remove();
                    $('#lead-report-opportunities-stage-per-rep').empty();
                    $('#lead-report-opportunities-stage-per-rep').removeClass('no-graph-data');
                    $('#lead-report-opportunities-stage-per-rep-card-comparison').empty();
                    if (typeof graphs.opportunitiesStagePerRep.axes !== 'undefined') {
                        chartData = [
                            graphs.opportunitiesStagePerRep.axes
                        ];

                        var opportunitiesGroupFrom = graphs.opportunitiesStagePerRep.opportunitiesGroupFrom,
                            groups = [],
                            onlyData = [],
                            compare = false;

                        groups.push(opportunitiesGroupFrom);

                        $.each(graphs.opportunitiesStagePerRep.data, function(opportunity, opportunityData){
                            chartData.push(opportunityData);
                            var cleanLegendId = '';

                            if (opportunityData[0].match(/\*/) !== null) {
                                cleanLegendId = opportunityData[0].substring(1);
                            } else {
                                cleanLegendId = opportunityData[0];
                            }
                            if (_.indexOf(onlyData, cleanLegendId) == '-1') {
                                onlyData.push(cleanLegendId);
                            }
                        });

                        if (typeof graphs.opportunitiesStagePerRep.dataToCompare !== 'undefined') {
                            groups.push(graphs.opportunitiesStagePerRep.opportunitiesGroupTo);
                            compare = true;
                        }
                        this.createBarChart(chartData, '#lead-report-opportunities-stage-per-rep', 45, {
                            groups:groups,
                            colorPattern: graphs.opportunitiesStagePerRep.colorPattern,
                            title: graphs.opportunitiesStagePerRep.title,
                            customYAxisFormat: {
                                type: 'onlyInteger'
                            },
                            tooltip: {filterFromDate: graphs.opportunitiesStagePerRep.filterFromDate, filterToDate: graphs.opportunitiesStagePerRep.filterToDate, compare:compare}
                        });
                        $('#lead-report-opportunities-stage-per-rep').find('svg').closest('div').after('<div id="lead-report-opportunities-stage-per-rep-tooltip"></div>');
                        this.createCustomLegend('#lead-report-opportunities-stage-per-rep-tooltip', '#lead-report-opportunities-stage-per-rep', onlyData,  graphs.opportunitiesStagePerRep.fullColorPattern);
                        if (typeof graphs.opportunitiesStagePerRep.dataToCompare !== 'undefined') {
                            $('#lead-report-opportunities-stage-per-rep').find('svg').before(_.template(CardComparisonTmpl, {'comparisonData': graphs.opportunitiesStagePerRep.comparisonData, 'i18n': i18n}));
                        }
                    } else {
                        $('#lead-report-opportunities-stage-per-rep').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n}));
                        $('#lead-report-opportunities-stage-per-rep').addClass('no-graph-data');
                    }
                }
            }
            if (tabName === 'group') {
                if (typeof graphs.byGroup !== 'undefined') {
                    $('#lead-report-by-group').empty();
                    $('#lead-report-by-group-card-comparison').empty();
                    $('#lead-report-by-group').removeClass('no-graph-data');
                    if (typeof graphs.byGroup.axes !== 'undefined') {
                        if (typeof graphs.byGroup.dataToCompare !== 'undefined') {
                            chartData = [
                                graphs.byGroup.axes,
                                graphs.byGroup.data,
                                graphs.byGroup.dataToCompare
                            ];
                        } else {
                            chartData = [
                                graphs.byGroup.axes,
                                graphs.byGroup.data
                            ];
                        }
                        this.createBarChart(chartData, '#lead-report-by-group', 45, {
                            colorPattern: graphs.byGroup.colorPattern,
                            labels: true,
                            title: graphs.byGroup.title,
                            customYAxisFormat: {
                                type: 'onlyInteger'
                            },
                            showLegend : true
                        });
                        if (typeof graphs.byGroup.dataToCompare !== 'undefined') {
                            $('#lead-report-by-group').find('svg').before(_.template(CardComparisonTmpl, {'comparisonData': graphs.byGroup.comparisonData, 'i18n': i18n}));
                        }
                    } else {
                        $('#lead-report-by-group').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n}));
                        $('#lead-report-by-group').addClass('no-graph-data');
                    }
                }
                if (typeof graphs.opportunityCountPerGroup !== 'undefined') {
                    $('#lead-report-opportunity-count-per-group').empty();
                    $('#lead-report-opportunity-count-per-group-card-comparison').empty();
                    $('#lead-report-opportunity-count-per-group').removeClass('no-graph-data');
                    if (typeof graphs.opportunityCountPerGroup.axes !== 'undefined') {
                        if (typeof graphs.opportunityCountPerGroup.dataToCompare !== 'undefined') {
                            chartData = [
                                graphs.opportunityCountPerGroup.axes,
                                graphs.opportunityCountPerGroup.data,
                                graphs.opportunityCountPerGroup.dataToCompare
                            ];
                        } else {
                            chartData = [
                                graphs.opportunityCountPerGroup.axes,
                                graphs.opportunityCountPerGroup.data
                            ];
                        }
                        this.createBarChart(chartData, '#lead-report-opportunity-count-per-group', 45, {
                            colorPattern: graphs.opportunityCountPerGroup.colorPattern,
                            labels: true,
                            title: graphs.opportunityCountPerGroup.title,
                            customYAxisFormat: {
                                type: 'onlyInteger'
                            },
                            showLegend : true
                        });
                        if (typeof graphs.opportunityCountPerGroup.dataToCompare !== 'undefined') {
                            $('#lead-report-opportunity-count-per-group').find('svg').before(_.template(CardComparisonTmpl, {'comparisonData': graphs.opportunityCountPerGroup.comparisonData, 'i18n': i18n}));
                        }
                    } else {
                        $('#lead-report-opportunity-count-per-group').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n}));
                        $('#lead-report-opportunity-count-per-group').addClass('no-graph-data');
                    }
                }
                if (typeof graphs.opportunityAmountByGroup !== 'undefined') {
                    $('#lead-report-opportunity-amount-by-group').empty();
                    $('#lead-report-opportunity-amount-by-group-card-comparison').empty();
                    $('#lead-report-opportunity-amount-by-group').removeClass('no-graph-data');
                    if (typeof graphs.opportunityAmountByGroup.axes !== 'undefined') {
                        if (typeof graphs.opportunityAmountByGroup.dataToCompare !== 'undefined') {
                            chartData = [
                                graphs.opportunityAmountByGroup.axes,
                                graphs.opportunityAmountByGroup.data,
                                graphs.opportunityAmountByGroup.dataToCompare
                            ];
                        } else {
                            chartData = [
                                graphs.opportunityAmountByGroup.axes,
                                graphs.opportunityAmountByGroup.data
                            ];
                        }
                        this.createBarChart(chartData, '#lead-report-opportunity-amount-by-group', 45, {
                            colorPattern: graphs.opportunityAmountByGroup.colorPattern,
                            customYAxisFormat: {
                                type: 'currency',
                                sign: this.LeadReportsCollection.currencySymbol

                            },
                            labels: {
                                type: 'currency',
                                sign: this.LeadReportsCollection.currencySymbol
                            },
                            title: graphs.opportunityAmountByGroup.title,
                            showLegend : true
                        });
                        if (typeof graphs.opportunityAmountByGroup.dataToCompare !== 'undefined') {
                            $('#lead-report-opportunity-amount-by-group').find('svg').before(_.template(CardComparisonTmpl, {'comparisonData': graphs.opportunityAmountByGroup.comparisonData, 'i18n': i18n}));
                        }
                    } else {
                        $('#lead-report-opportunity-amount-by-group').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n}));
                        $('#lead-report-opportunity-amount-by-group').addClass('no-graph-data');
                    }
                }

                if (typeof graphs.opportunityStagePerGroup !== 'undefined') {
                    $('#lead-report-opportunity-stage-per-group').empty();
                    $('#lead-report-opportunity-stage-per-group-legend').remove();
                    $('#lead-report-opportunity-stage-per-group-card-comparison').empty();
                    $('#lead-report-opportunity-stage-per-group').removeClass('no-graph-data');
                    if (typeof graphs.opportunityStagePerGroup.axes !== 'undefined') {
                        chartData = [
                            graphs.opportunityStagePerGroup.axes
                        ];


                        var opportunitiesGroupFrom = graphs.opportunityStagePerGroup.opportunitiesGroupFrom,
                            groups = [],
                            onlyData = [],
                            compare = false;

                        groups.push(opportunitiesGroupFrom);

                        $.each(graphs.opportunityStagePerGroup.data, function(opportunity, opportunityData){
                            var cleanLegendId = '';
                            if (!_.isArray(opportunityData)) {
                                var dataArr = [];
                                $.each(opportunityData, function(key, elem){
                                    dataArr[key] = elem;
                                });
                                chartData.push(dataArr);
                            } else {
                                chartData.push(opportunityData);
                            }

                            if (opportunityData[0].match(/\*/) !== null) {
                                cleanLegendId = opportunityData[0].substring(1);
                            } else {
                                cleanLegendId = opportunityData[0];
                            }
                            if (_.indexOf(onlyData, cleanLegendId) == '-1') {
                                onlyData.push(cleanLegendId);
                            }
                        });

                        if (typeof graphs.opportunityStagePerGroup.dataToCompare !== 'undefined') {
                            groups.push(graphs.opportunityStagePerGroup.opportunitiesGroupTo);
                            compare = true;
                        }
                        this.createBarChart(chartData, '#lead-report-opportunity-stage-per-group', 45, {
                            groups:groups,
                            colorPattern: graphs.opportunityStagePerGroup.colorPattern,
                            title: graphs.opportunityStagePerGroup.title,
                            customYAxisFormat: {
                                type: 'onlyInteger'
                            },
                            tooltip: {filterFromDate: graphs.opportunityStagePerGroup.filterFromDate, filterToDate: graphs.opportunityStagePerGroup.filterToDate, compare:compare}
                        });

                        $('#lead-report-opportunity-stage-per-group').find('svg').closest('div').after('<div id="lead-report-opportunity-stage-per-group-legend"></div>');
                        this.createCustomLegend('#lead-report-opportunity-stage-per-group-legend', '#lead-report-opportunity-stage-per-group', onlyData,  graphs.opportunityStagePerGroup.fullColorPattern);
                        if (typeof graphs.opportunityStagePerGroup.dataToCompare !== 'undefined') {
                            $('#lead-report-opportunity-stage-per-group').find('svg').before(_.template(CardComparisonTmpl, {'comparisonData': graphs.opportunityStagePerGroup.comparisonData, 'i18n': i18n}));
                        }
                    } else {
                        $('#lead-report-opportunity-stage-per-group').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n}));
                        $('#lead-report-opportunity-stage-per-group').addClass('no-graph-data');
                    }
                }
            }
            if (tabName === 'source') {
                if (typeof graphs.bySource !== 'undefined') {
                    $('#lead-report-by-source').empty();
                    $('#lead-report-by-source-card-comparison').empty();
                    $('#lead-report-by-source').removeClass('no-graph-data');
                    if (typeof graphs.bySource.axes !== 'undefined') {
                        if (typeof graphs.bySource.dataToCompare !== 'undefined') {
                            chartData = [
                                graphs.bySource.axes,
                                graphs.bySource.data,
                                graphs.bySource.dataToCompare
                            ];
                        } else {
                            chartData = [
                                graphs.bySource.axes,
                                graphs.bySource.data
                            ];
                        }
                        this.createBarChart(chartData, '#lead-report-by-source', 45, {
                            colorPattern: graphs.bySource.colorPattern,
                            labels: true,
                            title: graphs.bySource.title,
                            customYAxisFormat: {
                                type: 'onlyInteger'
                            },
                            showLegend : true
                        });
                        if (typeof graphs.bySource.dataToCompare !== 'undefined') {
                            $('#lead-report-by-source').find('svg').before(_.template(CardComparisonTmpl, {'comparisonData': graphs.bySource.comparisonData, 'i18n': i18n}));
                        }
                    } else {
                        $('#lead-report-by-source').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n}));
                        $('#lead-report-by-source').addClass('no-graph-data');
                    }
                }

                if (typeof graphs.opportunityCountPerSource !== 'undefined') {
                    $('#lead-report-opportunity-count-per-source').empty();
                    $('#lead-report-opportunity-count-per-source-card-comparison').empty();
                    $('#lead-report-opportunity-count-per-source').removeClass('no-graph-data');
                    if (typeof graphs.opportunityCountPerSource.axes !== 'undefined') {
                        if (typeof graphs.opportunityCountPerSource.dataToCompare !== 'undefined') {
                            chartData = [
                                graphs.opportunityCountPerSource.axes,
                                graphs.opportunityCountPerSource.data,
                                graphs.opportunityCountPerSource.dataToCompare
                            ];
                        } else {
                            chartData = [
                                graphs.opportunityCountPerSource.axes,
                                graphs.opportunityCountPerSource.data
                            ];
                        }
                        this.createBarChart(chartData, '#lead-report-opportunity-count-per-source', 45, {
                            colorPattern: graphs.opportunityCountPerSource.colorPattern,
                            labels: true,
                            title: graphs.opportunityCountPerSource.title,
                            customYAxisFormat: {
                                type: 'onlyInteger'
                            },
                            showLegend : true
                        });
                        if (typeof graphs.opportunityCountPerSource.dataToCompare !== 'undefined') {
                            $('#lead-report-opportunity-count-per-source').find('svg').before(_.template(CardComparisonTmpl, {'comparisonData': graphs.opportunityCountPerSource.comparisonData, 'i18n': i18n}));
                        }
                    } else {
                        $('#lead-report-opportunity-count-per-source').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n}));
                        $('#lead-report-opportunity-count-per-source').addClass('no-graph-data');
                    }
                }

                if (typeof graphs.opportunityAmountBySource !== 'undefined') {
                    $('#lead-report-opportunity-amount-by-source').empty();
                    $('#lead-report-opportunity-amount-by-source-card-comparison').empty();
                    $('#lead-report-opportunity-amount-by-source').removeClass('no-graph-data');
                    if (typeof graphs.opportunityAmountBySource.axes !== 'undefined') {
                        if (typeof graphs.opportunityAmountBySource.dataToCompare !== 'undefined') {
                            chartData = [
                                graphs.opportunityAmountBySource.axes,
                                graphs.opportunityAmountBySource.data,
                                graphs.opportunityAmountBySource.dataToCompare
                            ];
                        } else {
                            chartData = [
                                graphs.opportunityAmountBySource.axes,
                                graphs.opportunityAmountBySource.data
                            ];
                        }
                        this.createBarChart(chartData, '#lead-report-opportunity-amount-by-source', 45, {
                            colorPattern: graphs.opportunityAmountBySource.colorPattern,
                            customYAxisFormat: {
                                type: 'currency',
                                sign: this.LeadReportsCollection.currencySymbol

                            },
                            labels: {
                                type: 'currency',
                                sign: this.LeadReportsCollection.currencySymbol
                            },
                            title: graphs.opportunityAmountBySource.title,
                            showLegend : true
                        });
                        if (typeof graphs.opportunityAmountBySource.dataToCompare !== 'undefined') {
                            $('#lead-report-opportunity-amount-by-source').find('svg').before(_.template(CardComparisonTmpl, {'comparisonData': graphs.opportunityAmountBySource.comparisonData, 'i18n': i18n}));
                        }
                    } else {
                        $('#lead-report-opportunity-amount-by-source').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n}));
                        $('#lead-report-opportunity-amount-by-source').addClass('no-graph-data');
                    }
                }

                if (typeof graphs.opportunityStagePerSource !== 'undefined') {
                    $('#lead-report-opportunity-stage-per-source').empty();
                    $('#lead-report-opportunity-stage-per-source-legend').remove();
                    $('#lead-report-opportunity-stage-per-source-card-comparison').empty();
                    $('#lead-report-opportunity-stage-per-source').removeClass('no-graph-data');
                    if (typeof graphs.opportunityStagePerSource.axes !== 'undefined') {
                        chartData = [
                            graphs.opportunityStagePerSource.axes
                        ];

                        var opportunitiesGroupFrom = graphs.opportunityStagePerSource.opportunitiesGroupFrom,
                            groups = [],
                            onlyData = [],
                            compare = false;

                        groups.push(opportunitiesGroupFrom);

                        $.each(graphs.opportunityStagePerSource.data, function(opportunity, opportunityData){
                            var cleanLegendId = '';
                            if (!_.isArray(opportunityData)) {
                                var dataArr = [];
                                $.each(opportunityData, function(key, elem){
                                    dataArr[key] = elem;
                                });
                                chartData.push(dataArr);
                            } else {
                                chartData.push(opportunityData);
                            }

                            if (opportunityData[0].match(/\*/) !== null) {
                                cleanLegendId = opportunityData[0].substring(1);
                            } else {
                                cleanLegendId = opportunityData[0];
                            }
                            if (_.indexOf(onlyData, cleanLegendId) == '-1') {
                                onlyData.push(cleanLegendId);
                            }
                        });

                        if (typeof graphs.opportunityStagePerSource.dataToCompare !== 'undefined') {
                            groups.push(graphs.opportunityStagePerSource.opportunitiesGroupTo);
                            compare = true;
                        }

                        this.createBarChart(chartData, '#lead-report-opportunity-stage-per-source', 45, {
                            groups:groups,
                            colorPattern: graphs.opportunityStagePerSource.colorPattern,
                            title: graphs.opportunityStagePerSource.title,
                            customYAxisFormat: {
                                type: 'onlyInteger'
                            },
                            tooltip: {filterFromDate: graphs.opportunityStagePerSource.filterFromDate, filterToDate: graphs.opportunityStagePerSource.filterToDate, compare: compare}
                        });
                        $('#lead-report-opportunity-stage-per-source').find('svg').closest('div').after('<div id="lead-report-opportunity-stage-per-source-legend"></div>');
                        this.createCustomLegend('#lead-report-opportunity-stage-per-source-legend', '#lead-report-opportunity-stage-per-source', onlyData, graphs.opportunityStagePerSource.fullColorPattern);
                        if (typeof graphs.opportunityStagePerSource.dataToCompare !== 'undefined') {
                            $('#lead-report-opportunity-stage-per-source').find('svg').before(_.template(CardComparisonTmpl, {'comparisonData': graphs.opportunityStagePerSource.comparisonData, 'i18n': i18n}));
                        }
                    } else {
                        $('#lead-report-opportunity-stage-per-source').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n}));
                        $('#lead-report-opportunity-stage-per-source').addClass('no-graph-data');
                    }
                }
            }
            if (tabName === 'sales') {
                // move to Crm forecast tab
                //if (typeof graphs.opportunityStageFunnelOriginal !== 'undefined') {
                //    $('#lead-report-opportunity-stage-funnel').empty();
                //    $('#lead-report-opportunity-stage-funnel-title').remove();
                //    $('#lead-report-opportunity-stage-funnel').removeClass('no-graph-data');
                //    $('#lead-report-opportunity-stage-funnel-sales-expectation').remove();
                //    if (typeof graphs.opportunityStageFunnelOriginal.data !== 'undefined') {
                //        var chartData = [];
                //
                //        $.each(graphs.opportunityStageFunnelOriginal.data, function(opportunity, opportunityData){
                //            chartData.push([opportunityData.stageName +' ' + opportunity, parseInt(opportunityData.count), opportunityData.color]);
                //        });
                //
                //        this.createFunnelChart(chartData, '#lead-report-opportunity-stage-funnel', 25);
                //        $('#lead-report-opportunity-stage-funnel').before('<div id="lead-report-opportunity-stage-funnel-title"><span class="c3-title">'+graphs.opportunityStageFunnelOriginal.title+' for '+graphs.opportunityStageFunnelOriginal.filterPeriod+'</span></div>');
                //        if (typeof graphs.opportunityStageFunnelOriginal.salesExpectation !== 'undefined') {
                //            $('#lead-report-opportunity-stage-funnel').after('<div class="lead-report-opportunity-stage-funnel-sales-expectation-box" id="lead-report-opportunity-stage-funnel-sales-expectation"><span class="sales-expectation-label">Sale expectation</span><span class="sales-expectation-value">'+this.LeadReportsCollection.currencySymbol+graphs.opportunityStageFunnelOriginal.salesExpectation+'</span></div>');
                //        }
                //    } else {
                //        $('#lead-report-opportunity-stage-funnel').append(_.template(GraphPlaceholderTmpl));
                //        $('#lead-report-opportunity-stage-funnel-title').remove();
                //        $('#lead-report-opportunity-stage-funnel').addClass('no-graph-data');
                //    }
                //}
                //
                //if (typeof graphs.opportunityStageFunnelCompare !== 'undefined') {
                //    $('#lead-report-opportunity-stage-funnel-compare').empty();
                //    $('#lead-report-opportunity-stage-funnel-compare').parent('div').removeClass('hidden');
                //    $('#lead-report-opportunity-stage-funnel-compare-card-comparison').empty();
                //    $('#lead-report-opportunity-stage-funnel-compare-title').remove();
                //    $('#lead-report-opportunity-stage-funnel-compare-sales-expectation').remove();
                //    $('#lead-report-opportunity-stage-funnel-compare').removeClass('no-graph-data');
                //    if (typeof graphs.opportunityStageFunnelCompare.data !== 'undefined') {
                //        var chartData = [];
                //
                //        $.each(graphs.opportunityStageFunnelCompare.data, function(opportunity, opportunityData){
                //            chartData.push([opportunityData.stageName +' ' + opportunity, parseInt(opportunityData.count), opportunityData.color]);
                //        });
                //
                //        this.createFunnelChart(chartData, '#lead-report-opportunity-stage-funnel-compare', 25);
                //        $('#lead-report-opportunity-stage-funnel-compare').before('<div id="lead-report-opportunity-stage-funnel-compare-title"><span class="c3-title">'+graphs.opportunityStageFunnelCompare.title+' for '+graphs.opportunityStageFunnelCompare.filterPeriod+'</span></div>');
                //
                //    } else {
                //        $('#lead-report-opportunity-stage-funnel-compare').append(_.template(GraphPlaceholderTmpl));
                //        $('#lead-report-opportunity-stage-funnel-compare').addClass('no-graph-data');
                //    }
                //    if (typeof graphs.opportunityStageFunnelCompare.comparisonData !== 'undefined' && typeof graphs.opportunityStageFunnelCompare.data !== 'undefined') {
                //        $('#lead-report-opportunity-stage-funnel').find('svg').before(_.template(CardComparisonTmpl, {'comparisonData': graphs.opportunityStageFunnelCompare.comparisonData}));
                //    }
                //    if (typeof graphs.opportunityStageFunnelCompare.salesExpectation !== 'undefined') {
                //        $('#lead-report-opportunity-stage-funnel-compare').after('<div class="lead-report-opportunity-stage-funnel-sales-expectation-box" id="lead-report-opportunity-stage-funnel-compare-sales-expectation"><span class="sales-expectation-label">Sale expectation</span><span class="sales-expectation-value">'+this.LeadReportsCollection.currencySymbol+graphs.opportunityStageFunnelCompare.salesExpectation+'</span></div>');
                //    }
                //
                //} else {
                //    $('#lead-report-opportunity-stage-funnel-compare').empty();
                //    $('#lead-report-opportunity-stage-funnel-compare').parent('div').addClass('hidden');
                //    $('#lead-report-opportunity-stage-funnel-compare-title').remove();
                //}

                if (typeof graphs.opportunityStagePieOriginal !== 'undefined') {
                    $('#lead-report-opportunity-stage-pie-original').empty();
                    $('#lead-report-opportunity-stage-pie-original-legend').remove();
                    $('#lead-report-opportunity-stage-pie-original').removeClass('no-graph-data');
                    if (typeof graphs.opportunityStagePieOriginal.data !== 'undefined') {
                        var chartData = [],
                            labelsData = {};

                        $.each(graphs.opportunityStagePieOriginal.data, function(opportunity, opportunityData){
                            chartData.push([opportunityData.stageName, opportunityData.amount]);
                            if (opportunity === '100') {
                                labelsData.Won = 'Won with '+ opportunityData.count +' deals';
                            } else {
                                labelsData.Lost = 'Lost with '+ opportunityData.count +' deals';
                            }
                       });

                        this.createPieChart(chartData, '#lead-report-opportunity-stage-pie-original', 45, {
                            colorPattern: graphs.opportunityStagePieOriginal.colorPattern,
                            title: graphs.opportunityStagePieOriginal.title,
                            amountComparison: {
                                labelsData: labelsData,
                                sign: this.LeadReportsCollection.currencySymbol
                            }
                        });
                        $('#lead-report-opportunity-stage-pie-original').find('svg').closest('div').after('<div id="lead-report-opportunity-stage-pie-original-legend"><span>'+graphs.opportunityStagePieOriginal.filterPeriod+'</span></div>');
                    } else {
                        $('#lead-report-opportunity-stage-pie-original').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n}));
                        $('#lead-report-opportunity-stage-pie-original').addClass('no-graph-data');
                    }
                }

                if (typeof graphs.opportunityStagePieCompare !== 'undefined') {
                    $('#lead-report-opportunity-stage-pie-compare').empty();
                    $('#lead-report-opportunity-stage-pie-compare').parent('div').removeClass('hidden');
                    $('#lead-report-opportunity-stage-pie-compare-legend').remove();
                    $('#lead-report-opportunity-stage-pie-compare-card-comparison').empty();
                    $('#lead-report-opportunity-stage-pie-compare').removeClass('no-graph-data');
                    if (typeof graphs.opportunityStagePieCompare.data !== 'undefined') {
                        var chartData = [],
                            labelsData = {};

                        $.each(graphs.opportunityStagePieCompare.data, function(opportunity, opportunityData){
                            chartData.push([opportunityData.stageName, opportunityData.amount]);
                            if (opportunity === '100') {
                                labelsData.Won = 'Won with '+ opportunityData.count +' deals';
                            } else {
                                labelsData.Lost = 'Lost with '+ opportunityData.count +' deals';
                            }
                        });

                        this.createPieChart(chartData, '#lead-report-opportunity-stage-pie-compare', 45, {
                            colorPattern: graphs.opportunityStagePieCompare.colorPattern,
                            title: graphs.opportunityStagePieCompare.title,
                            amountComparison: {
                                labelsData: labelsData,
                                sign: this.LeadReportsCollection.currencySymbol
                            }
                        });
                        $('#lead-report-opportunity-stage-pie-compare').find('svg').closest('div').after('<div id="lead-report-opportunity-stage-pie-compare-legend"><span>'+graphs.opportunityStagePieCompare.filterPeriod+'</span></div>');

                    } else {
                        $('#lead-report-opportunity-stage-pie-compare').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n}));
                        $('#lead-report-opportunity-stage-pie-compare').addClass('no-graph-data');

                    }
                    if (typeof graphs.opportunityStagePieCompare.comparisonData !== 'undefined' && typeof graphs.opportunityStagePieCompare.data !== 'undefined') {
                        $('#lead-report-opportunity-stage-pie-original').find('svg').before(_.template(CardComparisonPieTmpl, {'comparisonData': graphs.opportunityStagePieCompare.comparisonData, 'i18n': i18n}));
                    }
                } else {
                    $('#lead-report-opportunity-stage-pie-compare').empty();
                    $('#lead-report-opportunity-stage-pie-compare').parent('div').addClass('hidden');
                    $('#lead-report-opportunity-stage-pie-compare-legend').remove();
                }

                if (typeof graphs.opportunityStagePerRepSale !== 'undefined') {
                    $('#lead-report-opportunity-stage-per-rep-sale-tooltip').remove();
                    $('#lead-report-opportunity-stage-per-rep-sale').empty().removeClass('no-graph-data');
                    $('#lead-report-opportunity-stage-per-rep-sale-card-comparison').empty();
                    if (typeof graphs.opportunityStagePerRepSale.axes !== 'undefined') {
                        chartData = [
                            graphs.opportunityStagePerRepSale.axes
                        ];

                        var opportunitiesGroupFrom = graphs.opportunityStagePerRepSale.opportunitiesGroupFrom,
                            groups = [],
                            onlyData = [],
                            compare = false;

                        groups.push(opportunitiesGroupFrom);

                        $.each(graphs.opportunityStagePerRepSale.data, function(opportunity, opportunityData){
                            chartData.push(opportunityData);
                            var cleanLegendId = '';

                            if (opportunityData[0].match(/\*/) !== null) {
                                cleanLegendId = opportunityData[0].substring(1);
                            } else {
                                cleanLegendId = opportunityData[0];
                            }
                            if (_.indexOf(onlyData, cleanLegendId) == '-1') {
                                onlyData.push(cleanLegendId);
                            }
                        });

                        if (typeof graphs.opportunityStagePerRepSale.dataToCompare !== 'undefined') {
                            groups.push(graphs.opportunityStagePerRepSale.opportunitiesGroupTo);
                            compare = true;
                        }
                        this.createBarChart(chartData, '#lead-report-opportunity-stage-per-rep-sale', 45, {
                            groups:groups,
                            colorPattern: graphs.opportunityStagePerRepSale.colorPattern,
                            title: graphs.opportunityStagePerRepSale.title,
                            customYAxisFormat: {
                                type: 'currency',
                                sign: this.LeadReportsCollection.currencySymbol
                            },
                            tooltip: {filterFromDate: graphs.opportunityStagePerRepSale.filterFromDate, filterToDate: graphs.opportunityStagePerRepSale.filterToDate, compare:compare, 'roughData':graphs.opportunityStagePerRepSale.roughData}
                        });
                        $('#lead-report-opportunity-stage-per-rep-sale').find('svg').closest('div').after('<div id="lead-report-opportunity-stage-per-rep-sale-tooltip"></div>');
                        this.createCustomLegend('#lead-report-opportunity-stage-per-rep-sale-tooltip', '#lead-report-opportunity-stage-per-rep-sale', onlyData,  graphs.opportunityStagePerRepSale.fullColorPattern);
                        if (typeof graphs.opportunityStagePerRepSale.dataToCompare !== 'undefined') {
                            $('#lead-report-opportunity-stage-per-rep-sale').find('svg').before(_.template(CardComparisonTmpl, {'comparisonData': graphs.opportunityStagePerRepSale.comparisonData, 'i18n': i18n}));
                        }
                    } else {
                        $('#lead-report-opportunity-stage-per-rep-sale').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n})).addClass('no-graph-data');
                    }
                }

                if (typeof graphs.opportunityStagePerSourceSale !== 'undefined') {
                    $('#lead-report-opportunity-stage-per-source-sale-tooltip').remove();
                    $('#lead-report-opportunity-stage-per-source-sale').empty().removeClass('no-graph-data');
                    $('#lead-report-opportunity-stage-per-source-sale-card-comparison').empty();
                    if (typeof graphs.opportunityStagePerSourceSale.axes !== 'undefined') {
                        chartData = [
                            graphs.opportunityStagePerSourceSale.axes
                        ];

                        var opportunitiesGroupFrom = graphs.opportunityStagePerSourceSale.opportunitiesGroupFrom,
                            groups = [],
                            onlyData = [],
                            compare = false;

                        groups.push(opportunitiesGroupFrom);

                        $.each(graphs.opportunityStagePerSourceSale.data, function(opportunity, opportunityData){
                            chartData.push(opportunityData);
                            var cleanLegendId = '';

                            if (opportunityData[0].match(/\*/) !== null) {
                                cleanLegendId = opportunityData[0].substring(1);
                            } else {
                                cleanLegendId = opportunityData[0];
                            }
                            if (_.indexOf(onlyData, cleanLegendId) == '-1') {
                                onlyData.push(cleanLegendId);
                            }
                        });

                        if (typeof graphs.opportunityStagePerSourceSale.dataToCompare !== 'undefined') {
                            groups.push(graphs.opportunityStagePerSourceSale.opportunitiesGroupTo);
                            compare = true;
                        }
                        this.createBarChart(chartData, '#lead-report-opportunity-stage-per-source-sale', 45, {
                            groups:groups,
                            colorPattern: graphs.opportunityStagePerSourceSale.colorPattern,
                            title: graphs.opportunityStagePerSourceSale.title,
                            customYAxisFormat: {
                                type: 'currency',
                                sign: this.LeadReportsCollection.currencySymbol
                            },
                            tooltip: {filterFromDate: graphs.opportunityStagePerSourceSale.filterFromDate, filterToDate: graphs.opportunityStagePerSourceSale.filterToDate, compare:compare, 'roughData':graphs.opportunityStagePerSourceSale.roughData}
                        });
                        $('#lead-report-opportunity-stage-per-source-sale').find('svg').closest('div').after('<div id="lead-report-opportunity-stage-per-source-sale-tooltip"></div>');
                        this.createCustomLegend('#lead-report-opportunity-stage-per-source-sale-tooltip', '#lead-report-opportunity-stage-per-source-sale', onlyData,  graphs.opportunityStagePerSourceSale.fullColorPattern);
                        if (typeof graphs.opportunityStagePerSourceSale.dataToCompare !== 'undefined') {
                            $('#lead-report-opportunity-stage-per-source-sale').find('svg').before(_.template(CardComparisonTmpl, {'comparisonData': graphs.opportunityStagePerSourceSale.comparisonData, 'i18n': i18n}));
                        }
                    } else {
                        $('#lead-report-opportunity-stage-per-source-sale').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n})).addClass('no-graph-data');
                    }
                }

                if (typeof graphs.opportunityStagePerGroupSale !== 'undefined') {
                    $('#lead-report-opportunity-stage-per-group-sale-tooltip').remove();
                    $('#lead-report-opportunity-stage-per-group-sale').empty().removeClass('no-graph-data');
                    $('#lead-report-opportunity-stage-per-group-sale-comparison').empty();
                    if (typeof graphs.opportunityStagePerGroupSale.axes !== 'undefined') {
                        chartData = [
                            graphs.opportunityStagePerGroupSale.axes
                        ];

                        var opportunitiesGroupFrom = graphs.opportunityStagePerGroupSale.opportunitiesGroupFrom,
                            groups = [],
                            onlyData = [],
                            compare = false;

                        groups.push(opportunitiesGroupFrom);

                        $.each(graphs.opportunityStagePerGroupSale.data, function(opportunity, opportunityData){
                            chartData.push(opportunityData);
                            var cleanLegendId = '';

                            if (opportunityData[0].match(/\*/) !== null) {
                                cleanLegendId = opportunityData[0].substring(1);
                            } else {
                                cleanLegendId = opportunityData[0];
                            }
                            if (_.indexOf(onlyData, cleanLegendId) == '-1') {
                                onlyData.push(cleanLegendId);
                            }
                        });

                        if (typeof graphs.opportunityStagePerGroupSale.dataToCompare !== 'undefined') {
                            groups.push(graphs.opportunityStagePerGroupSale.opportunitiesGroupTo);
                            compare = true;
                        }
                        this.createBarChart(chartData, '#lead-report-opportunity-stage-per-group-sale', 45, {
                            groups:groups,
                            colorPattern: graphs.opportunityStagePerGroupSale.colorPattern,
                            title: graphs.opportunityStagePerGroupSale.title,
                            customYAxisFormat: {
                                type: 'currency',
                                sign: this.LeadReportsCollection.currencySymbol
                            },
                            tooltip: {filterFromDate: graphs.opportunityStagePerGroupSale.filterFromDate, filterToDate: graphs.opportunityStagePerGroupSale.filterToDate, compare:compare, 'roughData':graphs.opportunityStagePerGroupSale.roughData}
                        });
                        $('#lead-report-opportunity-stage-per-group-sale').find('svg').closest('div').after('<div id="lead-report-opportunity-stage-per-group-sale-tooltip"></div>');
                        this.createCustomLegend('#lead-report-opportunity-stage-per-group-sale-tooltip', '#lead-report-opportunity-stage-per-group-sale', onlyData,  graphs.opportunityStagePerGroupSale.fullColorPattern);
                        if (typeof graphs.opportunityStagePerGroupSale.dataToCompare !== 'undefined') {
                            $('#lead-report-opportunity-stage-per-group-sale').find('svg').before(_.template(CardComparisonTmpl, {'comparisonData': graphs.opportunityStagePerGroupSale.comparisonData, 'i18n': i18n}));
                        }
                    } else {
                        $('#lead-report-opportunity-stage-per-group-sale').append(_.template(GraphPlaceholderTmpl, {'i18n': i18n})).addClass('no-graph-data');
                    }
                }
            }

        },
        showLeadReportsTab: function(e)
        {
            var el = $(e.currentTarget),
                tabBlockContentId = el.data('tab-id'),
                tabContentName = el.data('tab-name'),
                tabBlockContentEl = $('#'+tabBlockContentId),
                self = this,
                tabContentBlock = el.closest('#lead-reports-view-tabs-block').find('.lead-reports-view-tab-content');

            if (el.hasClass('current')) {
                return false;
            }

            tabContentBlock.addClass('hidden');
            $('#lead-reports-view-tabs').find('li').removeClass('current');
            this.hideTab(tabBlockContentEl, el);
            this.render();
        },
        switchCardComparison: function(e){
            var el = $(e.currentTarget),
                comparisonBlock = el.closest('.card-comparison-row').find('ul');

            if (comparisonBlock.hasClass('hidden')) {
                comparisonBlock.removeClass('hidden');
                el.removeClass('closed-comparison');
                el.text('collapse comparison');
            } else {
                comparisonBlock.addClass('hidden');
                el.addClass('closed-comparison');
                el.text('expand comparison');
            }
        },
        hideTab: function (tabBlockContentEl, el){
            tabBlockContentEl.removeClass('hidden');
            el.closest('li').addClass('current');
        },
        assign: function (selector, view) {
            var selectors;
            if (_.isObject(selector)) {
                selectors = selector;
            }
            else {
                selectors = {};
                selectors[selector] = view;
            }
            if (!selectors) return;
            _.each(selectors, function (view, selector) {
                view.setElement(this.$(selector)).render();
            }, this);
        },
        createFunnelChart: function(chartData, chartEl, percent, customParamsData)
        {
            var height = this.processWidth(percent),
                width = this.processWidth(percent);

            if (typeof customParamsData !== 'undefined' && typeof customParamsData.percentFromEl !== 'undefined') {
                height =  this.processWidth(percent, chartEl);
                width  =  this.processWidth(percent, chartEl);
            }

            var options = {
                chart: {
                    width: width,
                    height: height,
                    curve: 'enabled',
                    bottomWidth: 3 / 8,
                    bottomPinch: 0

                },
                block: {
                    minHeight: 10,
                    dynamicHeight: true,
                    highlight: true
                },
                label: {
                    format: '{f}\n{l}'
                },
                events: {
                    click: {
                        block: function(d) {
                            console.log(d.label.row);
                        }
                    }
                }
            };

            var chart = new D3Funnel(chartEl);
            chart.draw(chartData, options);
        },
        createPieChart: function(chartData, chartEl, percent, customParamsData)
        {
            var barWidth = this.processWidth(percent),
                colorPattern = [],
                title = '',
                showLegend = false;

            if (typeof customParamsData.colorPattern !== 'undefined') {
                colorPattern = customParamsData.colorPattern;
            }

            if (typeof customParamsData.title !== 'undefined') {
                title = customParamsData.title;
            }

            var chart = c3.generate({
                bindto: chartEl,
                onresize: function(){
                    chart.resize({
                        width:  barWidth,
                        height: barWidth/2
                    });
                },
                size: {
                    width: barWidth,
                    height: barWidth/2
                },
                data: {
                    columns: chartData,
                    type : 'pie'
                },
                title: {
                    text: title,
                    position: 'top-center'
                },
                color: {
                    pattern: colorPattern
                },
                //pie: {
                //    label: {
                //        format: function (value, ratio, id) {
                //            if (typeof customParamsData.amountComparison !== 'undefined') {
                //                if (id == 'Won') {
                //                    return d3.format('$')(value) +' '+ customParamsData.amountComparison.labelsData.Won;
                //                } else {
                //                    return d3.format('$')(value) +' '+ customParamsData.amountComparison.labelsData.Lost;
                //                }
                //            }
                //        }
                //    }
                //},
                //Alternative tooltip
                tooltip: {
                    format: {
                        title: function(d){return null;},
                        value: function (value, ratio, id) {
                            if (typeof customParamsData.amountComparison !== 'undefined') {
                                if (id == 'Won') {
                                    return customParamsData.amountComparison.sign + d3.format(",")(value) + ' ' + customParamsData.amountComparison.labelsData.Won;
                                } else {
                                    return customParamsData.amountComparison.sign + d3.format(",")(value) + ' ' + customParamsData.amountComparison.labelsData.Lost;
                                }
                            }
                        },
                        name: function(){return '';}
                    }
                },
                legend: {
                        show: showLegend,
                        position: 'bottom'
                }
            });

            // find all the labels
            d3.selectAll(".c3-chart-arc>text")
                .attr("transform", function(d,i){
                    var r = 90, //<-- adjust this to move the labels
                        a = (d.startAngle + d.endAngle) / 2 - (Math.PI / 2);
                    // compute the new centroid
                    return "translate(" + (Math.cos(a) * r) + "," + (Math.sin(a) * r) + ")";
                });
        },
        createBarChart: function(chartData, chartEl, percent, customParamsData) {
            var barWidth = this.processWidth(percent),
                yAxisTick =  {
                    centered: true,
                    outer: false
                },
                showLegend = false,
                groups = [],
                order = null,
                colorPattern = [],
                labels = [],
                title = '',
                tooltip = true,
                compare = false,
                roughData = {},
                self = this;

            if (typeof customParamsData !== 'undefined') {
                if(typeof customParamsData.showLegend !== 'undefined'){
                    showLegend = true;
                }

                if (typeof customParamsData.customYAxisFormat !== 'undefined') {
                    if (customParamsData.customYAxisFormat.type === 'currency') {
                        yAxisTick.format = function(d) { return customParamsData.customYAxisFormat.sign + d3.format(",")(d); }
                    }

                    if (customParamsData.customYAxisFormat.type === 'onlyInteger') {
                        yAxisTick.format = d3.format("d")
                    }
                }

                if (typeof customParamsData.groups !== 'undefined') {
                    groups = customParamsData.groups;
                }

                if (typeof customParamsData.colorPattern !== 'undefined') {
                    colorPattern = customParamsData.colorPattern;
                }

                if (typeof customParamsData.title !== 'undefined') {
                    title = customParamsData.title;
                }

                if (typeof customParamsData.labels !== 'undefined') {
                    if (typeof customParamsData.labels.type !== 'undefined' && customParamsData.labels.type === 'currency') {
                        labels = {
                            format: function (v, id, i, j) {
                                if (v !== 0) {
                                    return customParamsData.labels.sign + d3.format(",")(v);
                                }
                            }
                        }
                    } else {
                        labels = {
                            format: function (v, id, i, j) {
                                if (v !== 0) {
                                    return v;
                                }
                            }
                        }
                    }
                }

                if (typeof customParamsData.tooltip !== 'undefined') {
                    if (customParamsData.tooltip.compare !== 'undefined' && customParamsData.tooltip.compare === true) {
                        compare = true;
                    }

                    if (customParamsData.tooltip.roughData !== 'undefined') {
                        roughData = customParamsData.tooltip.roughData;
                    }

                    tooltip = {
                        format: {
                            //value: function (value, ratio, id) {
                            //    return value;
                            //},
                            //name: function (value, ratio, id) {
                            //    if (id.match(/\*/) !== null) {
                            //        return id.replace('*', '') + ' ' + customParamsData.tooltip.filterToDate;
                            //    } else {
                            //        return id  + ' ' + customParamsData.tooltip.filterFromDate;
                            //    }
                            //}

                        },
                        contents: function (d, defaultTitleFormat, defaultValueFormat, color) {
                            var $$ = this, config = $$.config,
                                titleFormat = config.tooltip_format_title || defaultTitleFormat,
                                nameFormat = config.tooltip_format_name || function (name) { return name; },
                                valueFormat = config.tooltip_format_value || defaultValueFormat,
                                text, i, title, value, name, bgcolor,
                                dataParams = {},
                                usedParams = {},
                                textItemRow = '';

                            for (i = 0; i < d.length; i++) {
                                if (! (d[i] && (d[i].value || d[i].value === 0))) { continue; }
                                name = nameFormat(d[i].name);
                                value = valueFormat(d[i].value, d[i].ratio, d[i].id, d[i].index);
                                bgcolor = $$.levelColor ? $$.levelColor(d[i].value) : color(d[i].id);
                                title = titleFormat ? titleFormat(d[i].x) : d[i].x;
                                dataParams[name] = {'value' : value, 'bgcolor' : bgcolor, 'line': d[i].id};
                                if (!_.isEmpty(roughData)) {
                                    var roughDataItem = _.find(roughData, function(item) {
                                        if (name.match(/\*/) !== null && compare === true) {
                                            return (item.full_name == title && item.type == 'previous' && item.description == name.substring(1));
                                        } else {
                                            return (item.full_name == title && item.type == 'current' && item.description == name);
                                        }
                                    });

                                    dataParams[name].amount = accounting.formatMoney(Math.round(roughDataItem.amount), JSON.parse(self.LeadReportsCollection.moneyFormat));
                                    dataParams[name].count = roughDataItem.count;
                                } else {
                                    dataParams[name].amount = '';
                                    dataParams[name].count = '';
                                }

                            }

                            for (key in dataParams) {
                                if (!text) {
                                    text = "<table class='" + $$.CLASS.tooltip + "'>" + "<tr><th style='text-align: center'>" + title + "</th><th style='text-align: center'>"+customParamsData.tooltip.filterFromDate+"</th>";
                                    if (compare === true) {
                                        text += "<th style='text-align: center'>"+customParamsData.tooltip.filterToDate+"</th></tr>";
                                    }
                                }


                                if ((typeof usedParams[key] !== 'undefined' || typeof usedParams[key.substring(1)] !== 'undefined') && compare === true) {
                                    continue;
                                }

                                text += "<tr class='" + $$.CLASS.tooltipName + "-" + key + "'>";


                                if (key.match(/\*/) !== null) {
                                    text += "<td class='name'><span style='background-color:" + dataParams[key]['bgcolor'] + "'></span>" + key.substring(1)+"</td>";
                                } else {
                                    text += "<td class='name'><span style='background-color:" + dataParams[key]['bgcolor'] + "'></span>" + key+"</td>";
                                }

                                if (key.match(/\*/) !== null && compare === true) {
                                    if (typeof dataParams[key.substring(1)] !== 'undefined') {
                                        if (typeof dataParams[key.substring(1)]['count'] !== 'undefined' && dataParams[key.substring(1)]['count'] !== '') {
                                            textItemRow = dataParams[key.substring(1)]['value']  + ' ('+dataParams[key.substring(1)]['count']+')';
                                        } else {
                                            textItemRow = dataParams[key.substring(1)]['value'];
                                        }
                                        text += "<td  style='text-align:center;' class='value'>" + textItemRow + "</td>";

                                    } else {
                                        text += "<td  style='text-align:center;' class='value'>" + 0 + "</td>";
                                    }
                                    if (typeof dataParams[key]['count'] !== 'undefined' && dataParams[key]['count'] !== '') {
                                        textItemRow = dataParams[key]['value'] + ' ('+ dataParams[key]['count']+')';
                                    } else {
                                        textItemRow =  dataParams[key]['value'];
                                    }
                                    text += "<td  style='text-align:center;' class='value'>"+ textItemRow + "</td>";
                                } else if (compare === true){
                                    if (typeof dataParams[key]['count'] !== 'undefined' && dataParams[key]['count'] !== '') {
                                        textItemRow = dataParams[key]['value'] + ' ('+ dataParams[key]['count']+ ')';
                                    } else {
                                        textItemRow = dataParams[key]['value'];
                                    }
                                    text += "<td  style='text-align:center;'  class='value'>"+ textItemRow + "</td>";
                                    if (typeof dataParams['*'+key] !== 'undefined') {
                                        if (typeof dataParams['*'+key]['count'] !== 'undefined' && dataParams['*'+key]['count'] !== '') {
                                            textItemRow = dataParams['*'+key]['value'] + ' ('+ dataParams['*'+key]['count']+ ')';
                                        } else {
                                            textItemRow = dataParams['*'+key]['value'];
                                        }
                                        text += "<td  style='text-align:center;' class='value'>" + textItemRow + "</td>";
                                    } else {
                                        text += "<td  style='text-align:center;' class='value'>" + 0 + "</td>";
                                    }
                                } else {
                                    if (typeof dataParams[key]['count'] !== 'undefined' && dataParams[key]['count'] !== '') {
                                        textItemRow =  dataParams[key]['value'] + ' ('+dataParams[key]['count']+')';
                                    } else {
                                        textItemRow = dataParams[key]['value'];
                                    }
                                    text += "<td  style='text-align:center;' class='value'>" + textItemRow + "</td>";
                                }


                                text += "</tr>";

                                usedParams[key] = true;
                            }

                            return text + "</table>";
                        }
                    }
                }
            }

            var chart = c3.generate({
                bindto: chartEl,
                size: {
                    width: barWidth,
                    height: barWidth/2.5
                },
                onresize: function(){
                    chart.resize({
                        width:  barWidth,
                        height: barWidth/2.5
                    });
                },
                data: {
                    x: 'x',
                    columns:chartData,
                    type: 'bar',
                    groups:groups,
                    order: order,
                    labels: labels
                },
                color: {
                    pattern: colorPattern
                },
                axis: {
                    rotated: true,
                    x: {
                        type: 'category',
                        show: true,
                        tick: {
                            centered: true
                        }
                    },
                    y:{
                        show: true,
                        tick: yAxisTick
                    }
                },
                grid: {
                    x: {
                        show: true
                    }
                },
                title: {
                    text: title,
                    position: 'top-center'
                },
                legend: {
                    show: showLegend,
                    position: 'bottom'
                },
                tooltip: tooltip

            });

            $(chartEl).data('c3-chart', chart);
        },
        processWidth: function(percent, element){
            if (typeof element !== 'undefined') {
                return (($(element).width() * percent) / 100);
            } else {
                return (($(document).width() * percent) / 100);
            }
        },
        processHeight: function(percent, element){
            if (typeof element !== 'undefined') {
                return (($(element).height() * percent) / 100);
            } else {
                return (($(document).height() * percent) / 100);
            }
        },
        createCustomLegend: function(legend, chartEl, xValues, fullColorPattern){
            $('.chart-legend', legend).remove();
            d3.select(legend).append('ul').attr('class', 'chart-legend pl0px')
                .selectAll('li')
                .data(xValues)
                .enter()
                .append('li')
                .style('white-space', 'nowrap')
                .attr('data-id', function (id) { return id; })
                .on('mouseover', function (id) {
                    if(!$(this).hasClass('clicked')) {
                        $(chartEl).data('c3-chart').focus(id);
                        $('li:not([data-id="' + id + '"])', legend).css('opacity', '0.3');
                    }
                })
                .on('mouseout', function (id) {
                    $(chartEl).data('c3-chart').revert();
                    $('li:not(".clicked")', legend).css('opacity', '1');
                })
                .on('click', function (id) {
                    if (id.match(/\*/) !== null) {
                        $(chartEl).data('c3-chart').toggle(id);
                        $(chartEl).data('c3-chart').toggle(id.substring(1));
                    } else {
                        $(chartEl).data('c3-chart').toggle(id);
                        $(chartEl).data('c3-chart').toggle('*'+id);
                    }

                    $(chartEl).data('c3-chart').revert();
                    if(!$(this).hasClass('clicked')) {
                        $(this).addClass('clicked');
                        $(this).css('opacity', '0.3');
                        $('li:not(".clicked")', legend).css('opacity', '1');
                    }
                    else{
                        $('li:not(".clicked")', legend).css('opacity', '0.3');
                        $(this).removeClass('clicked');
                        $(this).css('opacity', '1');
                        if (id.match(/\*/) !== null) {
                            $(chartEl).data('c3-chart').focus(id);
                            $(chartEl).data('c3-chart').focus(id.substring(1))
                        } else {
                            $(chartEl).data('c3-chart').focus(id);
                            $(chartEl).data('c3-chart').focus('*'+id)
                        }
                    }
                })
                .append('span')
                .each(function (id) {

                    var colorId = id;
                    if (!_.has(fullColorPattern, id)) {
                        colorId = '*'+id;
                    }

                    var color = fullColorPattern[colorId];

                  //  d3.select(this).style('background-color', $(chartEl).data('c3-chart').color(id));
                    d3.select(this).style('background-color', color);
                    $(this).after('<i> '+ id + '</i>');
                });
        }

    });

    return LeadReportsView;
});