define([
    'backbone',
    'text!../templates/lead-call-detailed-tab.html',
    'i18n!../../../nls/dashboard_'+$('#main-dashboard-system-language').val()+'_ln'
], function(Backbone, DetailedCallTmpl, i18n){
    var LeadCallFormView = Backbone.View.extend({
        el: $('#lead-detailed-view-config-tab-call'),
        events: {
            'submit form': 'submit',
            'change #call-device-type': 'selectCallDevice',
            'change #lead-phone-mobile-country-codes': 'changeCountryCode'
        },
        templates: {

        },
        initialize: function(leadModel){
            this.leadModel = leadModel;
        },
        render: function(){
            this.$el.empty();
            this.$el.html(_.template(DetailedCallTmpl, {'leadModel': this.leadModel, 'i18n' : i18n}));
            var mobileMasks = this.leadModel.get('mobileMasks'),
                mobileCountryCode = this.leadModel.get('lead_mobile_country_code'),
                currentMobileCountryCode = this.attributes.currentMobileCountryCode,
                currentDesktopCountryCode = this.attributes.currentDesktopCountryCode;

            if (typeof mobileMasks[mobileCountryCode] !== 'undefined') {
                $('#lead-call-number').mask(mobileMasks[mobileCountryCode].mask_value, {autoclear: false});
            } else {
                $('#lead-call-number').mask('(999) 999 9999', {autoclear: false});
            }

            if (typeof mobileMasks[currentMobileCountryCode] !== 'undefined') {
                $('#lead-from-call-mobile').mask(mobileMasks[currentMobileCountryCode].mask_value, {autoclear: false});
            } else {
                $('#lead-from-call-mobile').mask('(999) 999 9999', {autoclear: false});
            }
            var mobile = _.isUndefined(i18n['Mobile'])?'Mobile':i18n['Mobile'];
            $('#lead-from-call-mobile-number').text(mobile + ' ' + $('#lead-from-call-mobile').val());

            if (typeof mobileMasks[currentDesktopCountryCode] !== 'undefined') {
                $('#lead-from-call-desktop').mask(mobileMasks[currentDesktopCountryCode].mask_value, {autoclear: false});
            } else {
                $('#lead-from-call-desktop').mask('(999) 999 9999', {autoclear: false});
            }
            var desktop = _.isUndefined(i18n['Desktop'])?'Desktop':i18n['Desktop'];
            $('#lead-from-call-desktop-number').text(desktop + ' ' + $('#lead-from-call-desktop').val());

            this.$el.find('form').attr('action', $('#website_url').val()+'plugin/leads/run/callLead/');
            return this;
        },
        submit: function(e){
            e.preventDefault();

            var self = this,
                form = $(e.currentTarget),
                isValid = true;

            _.each(form.find('.required'), function(el){
                if (!$(el).val()){
                    isValid = false;
                }
            });

            if (!isValid){
                showMessage(_.isUndefined(i18n['Missing required field'])?'Missing required field':i18n['Missing required field'], true);
                return false;
            }

            var formParams = form.serialize()+'&secureToken='+$('#lead-grid-token').val();

            $.ajax({
                url: form.attr('action'),
                type: 'POST',
                data: formParams,
                dataType: 'json'
            }).done(function(response) {
                showMessage(response.responseText, false, 5000);
            }).fail(function(response){
                showMessage(response.responseJSON, true, 5000);
            });

            return false;

        },
        selectCallDevice: function(e)
        {
            var deviceTypeEl = $(e.currentTarget),
                deviceType = deviceTypeEl.val(),
                phoneEl = deviceTypeEl.closest('form').find('input[name="lead-call-number"]'),
                mobile = '',
                mobileCountyCode = '',
                phone = '',
                phoneCountryCode ='',
                desktopMasks = this.leadModel.get('desktopMasks'),
                mobileMasks = this.leadModel.get('mobileMasks');

            if (deviceType === 'mobile') {
                if (!_.isNull(this.leadModel.get('lead_mobile'))) {
                    mobile = this.leadModel.get('lead_mobile');
                }
                if (!_.isNull(this.leadModel.get('lead_mobile_country_code'))) {
                    mobileCountyCode = this.leadModel.get('lead_mobile_country_code');
                }
                if (_.isEmpty(mobileCountyCode)) {
                    $('#lead-phone-mobile-country-codes').val('AC');
                } else {
                    $('#lead-phone-mobile-country-codes').val(mobileCountyCode);
                }
                phoneEl.val(mobile);

                if (typeof mobileMasks[mobileCountyCode] !== 'undefined') {
                    phoneEl.mask(mobileMasks[mobileCountyCode].full_mask_value, {autoclear: false}).focus();
                } else {
                    phoneEl.mask('(999) 999 9999', {autoclear: false}).focus();
                }
            }

            if (deviceType === 'desktop') {
                if (!_.isNull(this.leadModel.get('lead_phone'))) {
                    phone = this.leadModel.get('lead_phone');
                }
                if (!_.isNull(this.leadModel.get('lead_phone_country_code'))) {
                    phoneCountryCode = this.leadModel.get('lead_phone_country_code');
                }
                if (_.isEmpty(phoneCountryCode)) {
                    $('#lead-phone-mobile-country-codes').val('AC');
                } else {
                    $('#lead-phone-mobile-country-codes').val(phoneCountryCode);
                }
                phoneEl.val(phone);
                if (typeof desktopMasks[phoneCountryCode] !== 'undefined') {
                    phoneEl.mask(desktopMasks[phoneCountryCode].full_mask_value, {autoclear: false}).focus();
                } else {
                    phoneEl.mask('(999) 999 9999', {autoclear: false}).focus();
                }
            }
        },
        changeCountryCode: function(e)
        {
            var countryEl = $(e.currentTarget),
                chosenCountryCode = countryEl.val(),
                deviceType = $('#call-device-type').val(),
                desktopMasks = this.leadModel.get('desktopMasks'),
                mobileMasks = this.leadModel.get('mobileMasks');

            if (deviceType === 'mobile') {
                if (typeof mobileMasks[chosenCountryCode] !== 'undefined') {
                    $('#lead-call-number').mask(mobileMasks[chosenCountryCode].full_mask_value, {autoclear: false});
                } else {
                    $('#lead-call-number').mask('(999) 999 9999', {autoclear: false});
                }
            }

            if (deviceType === 'desktop') {
                if (typeof desktopMasks[chosenCountryCode] !== 'undefined') {
                    $('#lead-call-number').mask(desktopMasks[chosenCountryCode].full_mask_value, {autoclear: false});
                } else {
                    $('#lead-call-number').mask('(999) 999 9999', {autoclear: false});
                }
            }
        }
    });

    return LeadCallFormView;
});