define([
    'backbone',
    'text!../templates/lead-meeting-detailed-tab.html',
    'i18n!../../../nls/dashboard_'+$('#main-dashboard-system-language').val()+'_ln'
], function(Backbone, LeadMeetingTmpl, i18n){
    var LeadMeetingFormView = Backbone.View.extend({
        el: $('#lead-detailed-view-config-tab-meeting'),
        events: {
            'submit form': 'submit',
            'change #lead-meeting-allow-add-time': 'changeAllowTime'
        },
        templates: {

        },
        initialize: function(leadModel){
            this.leadModel = leadModel;
        },
        render: function(){
            this.$el.empty();
            this.$el.append(_.template(LeadMeetingTmpl, {'leadModel': this.leadModel, 'i18n': i18n}));
            this.$el.find('form').attr('action', $('#website_url').val()+'api/leads/leadmeeting');

            var leadMeetingStartTime = $('#lead-meeting-start-time'),
                leadMeetingEndTime = $('#lead-meeting-end-time');

            leadMeetingStartTime.datepicker({
                dateFormat: 'd-M-yy',
                defaultDate: "+1w",
                changeMonth: true,
                changeYear: true,
                yearRange: "c-5:c+5",
                minDate: 0,
                onSelect: function(selectedDate){
                    if (leadMeetingEndTime.val() === '') {
                        leadMeetingEndTime.datepicker("setDate", selectedDate);
                    }
                    if (selectedDate !== '') {
                        leadMeetingEndTime.datepicker("option", "minDate", selectedDate);
                    }
                }
            });
            leadMeetingEndTime.datepicker({
                dateFormat: 'd-M-yy',
                defaultDate: "+1w",
                changeMonth: true,
                changeYear: true,
                yearRange: "c-5:c+5",
                onSelect: function(selectedDate){
                    if (selectedDate !== '') {
                        leadMeetingStartTime.datepicker("option", "maxDate", selectedDate);
                    }
                }
            });
        },
        submit: function(e){
            e.preventDefault();

            var self = this,
                form = $(e.currentTarget).closest('form'),
                isValid = true,
                params = {},
                period = 'fixed',
                googleCalendar = 0,
                startTimeDate = ($('#lead-meeting-start-time').val()) ? $.datepicker.formatDate('yy-mm-dd', $('#lead-meeting-start-time').datepicker("getDate")): '',
                startTime = $('#lead-meeting-start-time-time').val(),
                endTimeDate =  ($('#lead-meeting-end-time').val()) ? $.datepicker.formatDate('yy-mm-dd', $('#lead-meeting-end-time').datepicker("getDate")): '',
                endTime = $('#lead-meeting-end-time-time').val();

            _.each(form.find('.required'), function(el){
                if (!$(el).val()){
                    isValid = false;
                }
            });

            if (!isValid){
                showMessage(_.isUndefined(i18n['Missing required field'])?'Missing required field':i18n['Missing required field'], true);
                return false;
            }


            if (_.isEmpty(startTimeDate) || _.isEmpty(endTimeDate)) {
                return false;
            }


            if ($('#lead-meeting-allow-add-time').is(':checked')) {
                period = 'all_day';
            } else {
                startTimeDate = startTimeDate+' '+startTime+':00:00';
                endTimeDate = endTimeDate+' '+endTime+':00:00';
            }

            if ($('#lead-meeting-send-google-calendar').is(':checked')) {
                googleCalendar = 1;
            }


            params = {'lead_id':form.find('input[name=lead_id]').val(),
                'start_time_date':startTimeDate,
                'end_time_date':endTimeDate,
                'location':form.find('input[name=lead-meeting-location]').val(),
                'invite_attendees': form.find('input[name=lead-meeting-invite-attendees]').val(),
                'period': period,
                'subject':form.find('input[name=lead-meeting-subject]').val(),
                'details': form.find('textarea[name=lead-meeting-details]').val(),
                'secureToken': $('#lead-grid-token').val(),
                'google_calendar' : googleCalendar,
                'startTime': startTime,
                'endTime':endTime
            };

            $.ajax({
                url: form.attr('action'),
                type: 'POST',
                data: $.param(params),
                dataType: 'json'
            }).done(function(response) {
                 showMessage(response.responseText, false, 5000);
                 form.find('textarea').val('');
                 form.find('input[type=text]').val('');
            }).fail(function(response){
                showMessage(response.responseJSON, true, 5000);
            });
            return false;

        },
        changeAllowTime: function(e){
            if ($(e.currentTarget).is(':checked')) {
               $('#lead-meeting-start-time-time').prop('disabled', true);
               $('#lead-meeting-end-time-time').prop('disabled', true);
            } else {
                $('#lead-meeting-start-time-time').prop('disabled', false);
                $('#lead-meeting-end-time-time').prop('disabled', false);
            }
        }
    });

    return LeadMeetingFormView;
});