define([
    'backbone',
    '../collections/lead-opportunity-timeline',
    'text!../templates/lead-opportunity-timeline.html',
    'text!../templates/lead-opportunity-timeline-filter.html',
    'text!../templates/paginator.html',
    '../models/lead-opportunity-quote',
    '../collections/lead-opportunities',
    'i18n!../../../nls/dashboard_'+$('#main-dashboard-system-language').val()+'_ln',
    'moment',
    'accounting'
], function(Backbone,
            LeadOpportunityTimelineCollection, LeadOpportunityTimelineTmpl, LeadOpportunityTimelineFilterTmpl, PaginatorTmpl, LeadOpportunityQuoteModel, LeadOpportunityCollection, i18n, moment, accounting
){

    var LeadOpportunityTimelineView = Backbone.View.extend({
        el: $('#lead-detailed-view-statistics-tab-opportunity'),
        events: {
            'click .create-new-quote-for-opportunity': 'createQuote',
            'click .remove-quote-opportunity': 'removeQuote',
            'click .remove-quote-opportunity-section': 'removeOpportunity',
            'click .edit-quote-opportunity-section': 'editOpportunity',
            'change #opportunity-timeline-filter': 'filterBy',
            'click td.lead-opportunity-timeline-grid-paginator a.page': 'navigate'
        },
        templates: {
            paginator: _.template(PaginatorTmpl)
        },
        initialize: function(leadId){
            this.opportunityTimeline = new LeadOpportunityTimelineCollection();
            this.opportunityTimeline.lead_id = leadId;
            this.opportunityTimeline.on('reset', this.renderTimeline, this);
            this.opportunityTimeline.on('add', this.renderTimeline, this);
            this.opportunityTimeline.on('destroy', this.renderTimeline, this);

        },
        render: function(param){
            if(!_.isUndefined(param)) {
                this.opportunityTimeline.currentPage = 0;
                this.keepFilter = true;
            } else {
                this.keepFilter = false;
            }

            this.opportunityTimeline.server_api = _.extend(this.opportunityTimeline.server_api, {
                'filter': function() {
                    return {
                        'filter-by-opportunity-stage': $('#opportunity-timeline-filter').val()
                    };
                }
            });

            this.opportunityTimeline.pager();
        },
        renderTimeline: function(){
            this.previousOpportunity = false;
            this.$el.find('tbody').empty();
            if (!this.keepFilter) {
                this.$el.find('#lead-opportunity-filter-block').empty();
                this.$el.find('#lead-opportunity-filter-block').append(_.template(LeadOpportunityTimelineFilterTmpl, {'opportunityStages': this.opportunityTimeline.opportunityStages, 'i18n' : i18n}));
            }
            this.opportunityTimeline.each(this.renderTimelineItem, this);
            this.opportunityTimeline.info()['i18n'] = i18n;
            this.$('td.lead-opportunity-timeline-grid-paginator').html(this.templates.paginator(this.opportunityTimeline.information));
            if (typeof tableResponsive === "function") {
                tableResponsive();
            }
         },

        renderTimelineItem: function(opportunityData) {
            var newOpportunityRow = false,
                opportunityId = opportunityData.get('opportunity_id');
            if (_.isUndefined(this.previousOpportunity) || this.previousOpportunity !== opportunityId) {
                this.previousOpportunity = opportunityId;
                newOpportunityRow = true;
            }

            this.$el.find('tbody').append(_.template(LeadOpportunityTimelineTmpl, {
                'opportunityData': opportunityData, 'newOpportunityRow':newOpportunityRow,
                'opportunityStages':this.opportunityTimeline.opportunityStages,
                'users':this.opportunityTimeline.usersList,
                'currentUserId':this.opportunityTimeline.currentUserId,
                'currencySymbol':this.opportunityTimeline.currencySymbol,
                'expectedCloseDate': moment(opportunityData.get('expected_close_date'), 'YYYY-MM-DD HH:mm:ss').format('DD-MMM-YYYY'),
                'moment': moment,
                'accounting': accounting,
                'moneyFormat': this.opportunityTimeline.moneyFormat,
                'i18n' : i18n
            }));
        },
        editOpportunity: function(e)
        {
            e.preventDefault();
            var delLinkEl = $(e.currentTarget),
                opportunityId = delLinkEl.data('quote-opportunity-id'),
                opportunityTabEl = $('#lead-detailed-view-config-tabs-tab').find('[data-tab-id="lead-detailed-view-config-tab-opportunity"]');
            opportunityTabEl.addClass('remoteOpen').data('checked-opportunity-id', opportunityId).trigger('click');
            $('body,html').animate({
                scrollTop: $('#lead-detailed-view-config-tabs-tab').offset().top - 300
            }, 1000);

        },
        createQuote: function(e)
        {
            e.preventDefault();

            var self = this,
                quoteTitleElem = $(e.currentTarget).closest('td').find('.create-new-quote-for-opportunity-title'),
                leadId = quoteTitleElem.data('lead-id'),
                opportunityId = quoteTitleElem.data('lead-opportunity-id'),
                quoteLabel = quoteTitleElem.val();

            this.leadOpportunityQuoteModel = new LeadOpportunityQuoteModel();

            this.leadOpportunityQuoteModel.set('secureToken', $('#lead-grid-token').val());
            this.leadOpportunityQuoteModel.set('opportunity_id', opportunityId);
            this.leadOpportunityQuoteModel.set('lead_id', leadId);
            this.leadOpportunityQuoteModel.set('quote_title', quoteLabel);
            this.leadOpportunityQuoteModel.save(null, {
                success: function(model, response){
                    self.$el.trigger('opportunitiesQuotes:created');
                    showMessage(response.responseText.message, false, 5000);

                },
                error: function(model, response){
                    showMessage(response.responseText, true, 5000);
                }
            });
            return false;

        },
        filterBy: function(e)
        {
            e.preventDefault();
            this.$el.trigger('opportunitiesQuotes:created', true);
        },
        removeQuote: function(e)
        {
            var self = this;
            e.preventDefault();
            showConfirm(_.isUndefined(i18n['Are you sure want to delete'])?'Are you sure want to delete':i18n['Are you sure want to delete'], function(){
                var delLinkEl = $(e.currentTarget),
                    quoteId = delLinkEl.data('quote-id');

                $.ajax({
                    'url': $('#website_url').val() + 'api/quote/quotes/id/'+quoteId,
                    'type': 'DELETE',
                    'dataType': 'json'
                }).done(function(){
                    self.$el.trigger('opportunitiesQuotes:created', true);
                });
            });
        },
        removeOpportunity: function(e)
        {
            e.preventDefault();
            var self = this;
            showConfirm(_.isUndefined(i18n['Are you sure want to delete'])?'Are you sure want to delete':i18n['Are you sure want to delete'], function(){
                var delLinkEl = $(e.currentTarget),
                    opportunityId = delLinkEl.data('quote-opportunity-id');

                $.ajax({
                    'url': $('#website_url').val() + 'api/leads/leadopportunity/id/'+opportunityId,
                    'type': 'DELETE',
                    'dataType': 'json'
                }).done(function(response){
                    self.$el.trigger('opportunitiesQuotes:created', true);
                    showMessage(response.responseText, true, 5000);
                });
            });

        },
        navigate: function(e){
            e.preventDefault();

            var page = $(e.currentTarget).data('page');
            if ($.isNumeric(page)){
                this.opportunityTimeline.goTo(page);
            } else {
                switch(page){
                    case 'first':
                        this.opportunityTimeline.goTo(this.opportunityTimeline.firstPage);
                        break;
                    case 'last':
                        this.opportunityTimeline.goTo(this.opportunityTimeline.information.lastPage);
                        break;
                    case 'prev':
                        this.opportunityTimeline.requestPreviousPage();
                        break;
                    case 'next':
                        this.opportunityTimeline.requestNextPage();
                        break;
                }
            }
        }
    });

    return LeadOpportunityTimelineView;
});